@@ -1,8 +1,7 @@
 import json
-from datetime import datetime
+from datetime import datetime, timezone
 
 import boto3
-from dateutil.tz import tzlocal
 
 from moto import mock_aws
 
@@ -751,7 +750,8 @@ def test_create_job_template_with_simple_cloudformation():
     assert job_template["description"] == "Job template Description"
     assert job_template["document"] == '{"field": "value"}'
     assert job_template["documentSource"] == "a document source link"
-    assert job_template["createdAt"] == datetime(2015, 1, 1, 0, 0, tzinfo=tzlocal())
+    tzlocal = datetime.now(timezone.utc).astimezone().tzinfo
+    assert job_template["createdAt"] == datetime(2015, 1, 1, 0, 0, tzinfo=tzlocal)
     assert job_template["presignedUrlConfig"] == {
         "roleArn": "arn:aws:iam::1:role/service-role/iot_job_role",
         "expiresInSec": 123,
