@@ -1,18 +1,18 @@
-import datetime
 import re
 import time
+from datetime import datetime, timedelta
 
 import boto3
 import pytest
 from botocore.exceptions import ClientError
-from dateutil.tz import tzutc
 
 from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
+from moto.core.utils import utcnow
 
 
 @mock_aws
-def test_create_cluster_boto3():
+def test_create_cluster():
     client = boto3.client("redshift", region_name="us-east-1")
     response = client.create_cluster(
         DBName="test",
@@ -27,10 +27,8 @@ def test_create_cluster_boto3():
     assert cluster["NodeType"] == "ds2.xlarge"
     assert cluster["ClusterStatus"] == "creating"
     create_time = cluster["ClusterCreateTime"]
-    assert create_time < datetime.datetime.now(create_time.tzinfo)
-    assert create_time > (
-        datetime.datetime.now(create_time.tzinfo) - datetime.timedelta(minutes=1)
-    )
+    assert create_time < datetime.now(create_time.tzinfo)
+    assert create_time > (datetime.now(create_time.tzinfo) - timedelta(minutes=1))
     assert cluster["MasterUsername"] == "user"
     assert cluster["DBName"] == "test"
     assert cluster["AutomatedSnapshotRetentionPeriod"] == 1
@@ -67,10 +65,8 @@ def test_create_cluster_with_enhanced_vpc_routing_enabled():
     )
     assert response["Cluster"]["NodeType"] == "ds2.xlarge"
     create_time = response["Cluster"]["ClusterCreateTime"]
-    assert create_time < datetime.datetime.now(create_time.tzinfo)
-    assert create_time > (
-        datetime.datetime.now(create_time.tzinfo) - datetime.timedelta(minutes=1)
-    )
+    assert create_time < datetime.now(create_time.tzinfo)
+    assert create_time > (datetime.now(create_time.tzinfo) - timedelta(minutes=1))
     assert response["Cluster"]["EnhancedVpcRouting"] is True
 
 
@@ -220,7 +216,7 @@ def test_create_cluster_all_attributes():
 
 
 @mock_aws
-def test_create_single_node_cluster_boto3():
+def test_create_single_node_cluster():
     client = boto3.client("redshift", region_name="us-east-1")
     cluster_identifier = "my_cluster"
 
@@ -271,32 +267,7 @@ def test_create_cluster_in_subnet_group():
 
 
 @mock_aws
-def test_create_cluster_in_subnet_group_boto3():
-    ec2 = boto3.resource("ec2", region_name="us-east-1")
-    vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
-    subnet = ec2.create_subnet(VpcId=vpc.id, CidrBlock="10.0.0.0/24")
-    client = boto3.client("redshift", region_name="us-east-1")
-    client.create_cluster_subnet_group(
-        ClusterSubnetGroupName="my_subnet_group",
-        Description="This is my subnet group",
-        SubnetIds=[subnet.id],
-    )
-
-    client.create_cluster(
-        ClusterIdentifier="my_cluster",
-        NodeType="dw.hs1.xlarge",
-        MasterUsername="username",
-        MasterUserPassword="password",
-        ClusterSubnetGroupName="my_subnet_group",
-    )
-
-    cluster_response = client.describe_clusters(ClusterIdentifier="my_cluster")
-    cluster = cluster_response["Clusters"][0]
-    assert cluster["ClusterSubnetGroupName"] == "my_subnet_group"
-
-
-@mock_aws
-def test_create_cluster_with_security_group_boto3():
+def test_create_cluster_with_security_group():
     client = boto3.client("redshift", region_name="us-east-1")
     client.create_cluster_security_group(
         ClusterSecurityGroupName="security_group1",
@@ -324,7 +295,7 @@ def test_create_cluster_with_security_group_boto3():
 
 
 @mock_aws
-def test_create_cluster_with_vpc_security_groups_boto3():
+def test_create_cluster_with_vpc_security_groups():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
     client = boto3.client("redshift", region_name="us-east-1")
@@ -413,7 +384,7 @@ def test_describe_cluster_params():
 
 
 @mock_aws
-def test_create_cluster_with_parameter_group_boto3():
+def test_create_cluster_with_parameter_group():
     client = boto3.client("redshift", region_name="us-east-1")
     cluster_id = "my-cluster"
     group = client.create_cluster_parameter_group(
@@ -450,7 +421,7 @@ def test_create_cluster_with_parameter_group_boto3():
 
 
 @mock_aws
-def test_describe_non_existent_cluster_boto3():
+def test_describe_non_existent_cluster():
     client = boto3.client("redshift", region_name="us-east-1")
     with pytest.raises(ClientError) as ex:
         client.describe_clusters(ClusterIdentifier="not-a-cluster")
@@ -515,7 +486,7 @@ def test_modify_cluster_vpc_routing():
 
 
 @mock_aws
-def test_modify_cluster_boto3():
+def test_modify_cluster():
     client = boto3.client("redshift", region_name="us-east-1")
     cluster_identifier = "my_cluster"
     client.create_cluster_security_group(
@@ -591,7 +562,7 @@ def test_create_cluster_subnet_group():
     assert my_subnet["ClusterSubnetGroupName"] == "my_subnet_group"
     assert my_subnet["Description"] == "This is my subnet group"
     subnet_ids = [subnet["SubnetIdentifier"] for subnet in my_subnet["Subnets"]]
-    assert set(subnet_ids) == set([subnet1.id, subnet2.id])
+    assert set(subnet_ids) == {subnet1.id, subnet2.id}
 
 
 @mock_aws
@@ -647,7 +618,7 @@ def test_authorize_security_group_ingress():
 
 
 @mock_aws
-def test_create_invalid_cluster_subnet_group_boto3():
+def test_create_invalid_cluster_subnet_group():
     client = boto3.client("redshift", region_name="us-east-1")
     with pytest.raises(ClientError) as ex:
         client.create_cluster_subnet_group(
@@ -661,7 +632,7 @@ def test_create_invalid_cluster_subnet_group_boto3():
 
 
 @mock_aws
-def test_describe_non_existent_subnet_group_boto3():
+def test_describe_non_existent_subnet_group():
     client = boto3.client("redshift", region_name="us-east-1")
     with pytest.raises(ClientError) as ex:
         client.describe_cluster_subnet_groups(ClusterSubnetGroupName="my_subnet")
@@ -699,7 +670,7 @@ def test_delete_cluster_subnet_group():
 
 
 @mock_aws
-def test_create_cluster_security_group_boto3():
+def test_create_cluster_security_group():
     client = boto3.client("redshift", region_name="us-east-1")
     group = client.create_cluster_security_group(
         ClusterSecurityGroupName="my_security_group",
@@ -725,7 +696,7 @@ def test_create_cluster_security_group_boto3():
 
 
 @mock_aws
-def test_describe_non_existent_security_group_boto3():
+def test_describe_non_existent_security_group():
     client = boto3.client("redshift", region_name="us-east-1")
 
     with pytest.raises(ClientError) as ex:
@@ -736,7 +707,7 @@ def test_describe_non_existent_security_group_boto3():
 
 
 @mock_aws
-def test_delete_cluster_security_group_boto3():
+def test_delete_cluster_security_group():
     client = boto3.client("redshift", region_name="us-east-1")
     client.create_cluster_security_group(
         ClusterSecurityGroupName="my_security_group",
@@ -762,7 +733,7 @@ def test_delete_cluster_security_group_boto3():
 
 
 @mock_aws
-def test_create_cluster_parameter_group_boto3():
+def test_create_cluster_parameter_group():
     client = boto3.client("redshift", region_name="us-east-1")
     group = client.create_cluster_parameter_group(
         ParameterGroupName="my-parameter-group",
@@ -785,7 +756,7 @@ def test_create_cluster_parameter_group_boto3():
 
 
 @mock_aws
-def test_describe_non_existent_parameter_group_boto3():
+def test_describe_non_existent_parameter_group():
     client = boto3.client("redshift", region_name="us-east-1")
     with pytest.raises(ClientError) as ex:
         client.describe_cluster_parameter_groups(
@@ -797,7 +768,7 @@ def test_describe_non_existent_parameter_group_boto3():
 
 
 @mock_aws
-def test_delete_parameter_group_boto3():
+def test_delete_parameter_group():
     client = boto3.client("redshift", region_name="us-east-1")
     client.create_cluster_parameter_group(
         ParameterGroupName="my-parameter-group",
@@ -1929,9 +1900,7 @@ def test_get_cluster_credentials():
         NodeType="ds2.xlarge",
     )
 
-    expected_expiration = time.mktime(
-        (datetime.datetime.now(tzutc()) + datetime.timedelta(0, 900)).timetuple()
-    )
+    expected_expiration = time.mktime((utcnow() + timedelta(seconds=900)).timetuple())
     db_user = "some_user"
     response = client.get_cluster_credentials(
         ClusterIdentifier=cluster_identifier, DbUser=db_user
@@ -1952,9 +1921,7 @@ def test_get_cluster_credentials():
     )
     assert response["DbUser"] == "IAM:some_other_user"
 
-    expected_expiration = time.mktime(
-        (datetime.datetime.now(tzutc()) + datetime.timedelta(0, 3000)).timetuple()
-    )
+    expected_expiration = time.mktime((utcnow() + timedelta(seconds=3000)).timetuple())
     response = client.get_cluster_credentials(
         ClusterIdentifier=cluster_identifier, DbUser=db_user, DurationSeconds=3000
     )
