@@ -1,11 +1,14 @@
 import datetime
+from uuid import uuid4
 
 import boto3
 import pytest
 from botocore.client import ClientError
 
-from moto import mock_kms, mock_s3
+from moto import mock_aws
 from moto.s3.responses import DEFAULT_REGION_NAME
+from tests.test_s3 import generate_content_md5
+from tests.test_s3.test_s3 import enable_versioning
 
 from . import s3_aws_verified
 
@@ -19,27 +22,27 @@ from . import s3_aws_verified
         "key-with%2Fembedded%2Furl%2Fencoding",
     ],
 )
-@mock_s3
-def test_copy_key_boto3(key_name):
+@mock_aws
+def test_copy_key(key_name):
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    s3_resource.create_bucket(Bucket="foobar")
+    bucket = s3_resource.create_bucket(Bucket=str(uuid4()))
 
-    key = s3_resource.Object("foobar", key_name)
+    key = bucket.Object(key_name)
     key.put(Body=b"some value")
 
-    key2 = s3_resource.Object("foobar", "new-key")
-    key2.copy_from(CopySource=f"foobar/{key_name}")
+    key2 = bucket.Object("new-key")
+    key2.copy_from(CopySource=f"{bucket.name}/{key_name}")
 
-    resp = client.get_object(Bucket="foobar", Key=key_name)
+    resp = client.get_object(Bucket=bucket.name, Key=key_name)
     assert resp["Body"].read() == b"some value"
-    resp = client.get_object(Bucket="foobar", Key="new-key")
+    resp = client.get_object(Bucket=bucket.name, Key="new-key")
     assert resp["Body"].read() == b"some value"
 
 
 @pytest.mark.aws_verified
 @s3_aws_verified
-def test_copy_key_boto3_with_args(bucket=None):
+def test_copy_key_with_args(bucket_name=None):
     # Setup
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
@@ -47,13 +50,13 @@ def test_copy_key_boto3_with_args(bucket=None):
     new_key = "new_key"
     expected_hash = "qz0H8xacy9DtbEtF3iFRn5+TjHLSQSSZiquUnOg7tRs="
 
-    key = s3_resource.Object(bucket, key_name)
+    key = s3_resource.Object(bucket_name, key_name)
     key.put(Body=b"some value")
 
     # Execute
-    key2 = s3_resource.Object(bucket, new_key)
+    key2 = s3_resource.Object(bucket_name, new_key)
     key2.copy(
-        CopySource={"Bucket": bucket, "Key": key_name},
+        CopySource={"Bucket": bucket_name, "Key": key_name},
         ExtraArgs={
             "ChecksumAlgorithm": "SHA256",
             "WebsiteRedirectLocation": "http://getmoto.org/",
@@ -62,20 +65,20 @@ def test_copy_key_boto3_with_args(bucket=None):
 
     # Verify
     resp = client.get_object_attributes(
-        Bucket=bucket, Key=new_key, ObjectAttributes=["Checksum"]
+        Bucket=bucket_name, Key=new_key, ObjectAttributes=["Checksum"]
     )
 
     assert "Checksum" in resp
     assert "ChecksumSHA256" in resp["Checksum"]
     assert resp["Checksum"]["ChecksumSHA256"] == expected_hash
 
-    obj = client.get_object(Bucket=bucket, Key=new_key)
+    obj = client.get_object(Bucket=bucket_name, Key=new_key)
     assert obj["WebsiteRedirectLocation"] == "http://getmoto.org/"
 
     # Verify in place
     copy_in_place = client.copy_object(
-        Bucket=bucket,
-        CopySource=f"{bucket}/{new_key}",
+        Bucket=bucket_name,
+        CopySource=f"{bucket_name}/{new_key}",
         Key=new_key,
         ChecksumAlgorithm="SHA256",
         MetadataDirective="REPLACE",
@@ -87,7 +90,7 @@ def test_copy_key_boto3_with_args(bucket=None):
 
 @pytest.mark.aws_verified
 @s3_aws_verified
-def test_copy_key_boto3_with_args__using_multipart(bucket=None):
+def test_copy_key_with_args__using_multipart(bucket_name=None):
     # Setup
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
@@ -95,13 +98,13 @@ def test_copy_key_boto3_with_args__using_multipart(bucket=None):
     new_key = "new_key"
     expected_hash = "DnKotDi4EtYGwNMDKmnR6SqH3bWVOlo2BC+tsz9rHqw="
 
-    key = s3_resource.Object(bucket, key_name)
+    key = s3_resource.Object(bucket_name, key_name)
     key.put(Body=b"some value")
 
     # Execute
-    key2 = s3_resource.Object(bucket, new_key)
+    key2 = s3_resource.Object(bucket_name, new_key)
     key2.copy(
-        CopySource={"Bucket": bucket, "Key": key_name},
+        CopySource={"Bucket": bucket_name, "Key": key_name},
         ExtraArgs={
             "ChecksumAlgorithm": "SHA256",
             "WebsiteRedirectLocation": "http://getmoto.org/",
@@ -111,49 +114,51 @@ def test_copy_key_boto3_with_args__using_multipart(bucket=None):
 
     # Verify
     resp = client.get_object_attributes(
-        Bucket=bucket, Key=new_key, ObjectAttributes=["Checksum"]
+        Bucket=bucket_name, Key=new_key, ObjectAttributes=["Checksum"]
     )
 
     assert "Checksum" in resp
     assert "ChecksumSHA256" in resp["Checksum"]
     assert resp["Checksum"]["ChecksumSHA256"] == expected_hash
 
-    obj = client.get_object(Bucket=bucket, Key=new_key)
+    obj = client.get_object(Bucket=bucket_name, Key=new_key)
     assert obj["WebsiteRedirectLocation"] == "http://getmoto.org/"
 
 
-@mock_s3
-def test_copy_key_with_version_boto3():
+@mock_aws
+def test_copy_key_with_version():
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    s3_resource.create_bucket(Bucket="foobar")
+    bucket = s3_resource.create_bucket(Bucket=str(uuid4()))
     client.put_bucket_versioning(
-        Bucket="foobar", VersioningConfiguration={"Status": "Enabled"}
+        Bucket=bucket.name, VersioningConfiguration={"Status": "Enabled"}
     )
 
-    key = s3_resource.Object("foobar", "the-key")
+    key = bucket.Object("the-key")
     key.put(Body=b"some value")
     key.put(Body=b"another value")
 
-    all_versions = client.list_object_versions(Bucket="foobar", Prefix="the-key")[
+    all_versions = client.list_object_versions(Bucket=bucket.name, Prefix="the-key")[
         "Versions"
     ]
     old_version = [v for v in all_versions if not v["IsLatest"]][0]
 
-    key2 = s3_resource.Object("foobar", "new-key")
-    key2.copy_from(CopySource=f"foobar/the-key?versionId={old_version['VersionId']}")
+    key2 = bucket.Object("new-key")
+    key2.copy_from(
+        CopySource=f"{bucket.name}/the-key?versionId={old_version['VersionId']}"
+    )
 
-    resp = client.get_object(Bucket="foobar", Key="the-key")
+    resp = client.get_object(Bucket=bucket.name, Key="the-key")
     assert resp["Body"].read() == b"another value"
-    resp = client.get_object(Bucket="foobar", Key="new-key")
+    resp = client.get_object(Bucket=bucket.name, Key="new-key")
     assert resp["Body"].read() == b"some value"
 
 
-@mock_s3
+@mock_aws
 def test_copy_object_with_bucketkeyenabled_returns_the_value():
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "test-copy-object-with-bucketkeyenabled"
+    bucket_name = str(uuid4())
     s3_resource.create_bucket(Bucket=bucket_name)
 
     key = s3_resource.Object(bucket_name, "the-key")
@@ -185,56 +190,57 @@ def test_copy_object_with_bucketkeyenabled_returns_the_value():
     )
 
 
-@mock_s3
+@mock_aws
 def test_copy_key_with_metadata():
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    s3_resource.create_bucket(Bucket="foobar")
+    bucket = s3_resource.create_bucket(Bucket=str(uuid4()))
 
-    key = s3_resource.Object("foobar", "the-key")
+    key = bucket.Object("the-key")
     metadata = {"md": "Metadatastring"}
     content_type = "application/json"
     initial = key.put(Body=b"{}", Metadata=metadata, ContentType=content_type)
 
-    client.copy_object(Bucket="foobar", CopySource="foobar/the-key", Key="new-key")
+    client.copy_object(
+        Bucket=bucket.name, CopySource=f"{bucket.name}/the-key", Key="new-key"
+    )
 
-    resp = client.get_object(Bucket="foobar", Key="new-key")
+    resp = client.get_object(Bucket=bucket.name, Key="new-key")
     assert resp["Metadata"] == metadata
     assert resp["ContentType"] == content_type
     assert resp["ETag"] == initial["ETag"]
 
 
-@mock_s3
+@mock_aws
 def test_copy_key_replace_metadata():
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    s3_resource.create_bucket(Bucket="foobar")
+    bucket = s3_resource.create_bucket(Bucket=str(uuid4()))
 
-    key = s3_resource.Object("foobar", "the-key")
+    key = bucket.Object("the-key")
     initial = key.put(Body=b"some value", Metadata={"md": "Metadatastring"})
 
     client.copy_object(
-        Bucket="foobar",
-        CopySource="foobar/the-key",
+        Bucket=bucket.name,
+        CopySource=f"{bucket.name}/the-key",
         Key="new-key",
         Metadata={"momd": "Mometadatastring"},
         MetadataDirective="REPLACE",
     )
 
-    resp = client.get_object(Bucket="foobar", Key="new-key")
+    resp = client.get_object(Bucket=bucket.name, Key="new-key")
     assert resp["Metadata"] == {"momd": "Mometadatastring"}
     assert resp["ETag"] == initial["ETag"]
 
 
-@mock_s3
-def test_copy_key_without_changes_should_error():
+@s3_aws_verified
+@pytest.mark.aws_verified
+def test_copy_key_without_changes_should_error(bucket_name=None):
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "my_bucket"
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     key_name = "my_key"
     key = s3_resource.Object(bucket_name, key_name)
 
-    s3_resource.create_bucket(Bucket=bucket_name)
     key.put(Body=b"some value")
 
     with pytest.raises(ClientError) as exc:
@@ -250,15 +256,14 @@ def test_copy_key_without_changes_should_error():
         )
 
 
-@mock_s3
-def test_copy_key_without_changes_should_not_error():
+@s3_aws_verified
+@pytest.mark.aws_verified
+def test_copy_key_without_changes_should_not_error(bucket_name=None):
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "my_bucket"
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     key_name = "my_key"
     key = s3_resource.Object(bucket_name, key_name)
 
-    s3_resource.create_bucket(Bucket=bucket_name)
     key.put(Body=b"some value")
 
     client.copy_object(
@@ -274,18 +279,18 @@ def test_copy_key_without_changes_should_not_error():
     assert new_object["Metadata"] == {"some-key": "some-value"}
 
 
-@mock_s3
+@mock_aws
 def test_copy_key_reduced_redundancy():
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket = s3_resource.Bucket("test_bucket")
+    bucket = s3_resource.Bucket(str(uuid4()))
     bucket.create()
 
     bucket.put_object(Key="the-key", Body=b"somedata")
 
     client.copy_object(
-        Bucket="test_bucket",
-        CopySource="test_bucket/the-key",
+        Bucket=bucket.name,
+        CopySource=f"{bucket.name}/the-key",
         Key="new-key",
         StorageClass="REDUCED_REDUNDANCY",
     )
@@ -295,126 +300,135 @@ def test_copy_key_reduced_redundancy():
     assert keys["the-key"].storage_class == "STANDARD"
 
 
-@mock_s3
-def test_copy_non_existing_file():
+@s3_aws_verified
+@pytest.mark.aws_verified
+def test_copy_non_existing_file(bucket_name=None):
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
-    src = "srcbucket"
-    target = "target"
-    s3_resource.create_bucket(Bucket=src)
+    target = str(uuid4())
     s3_resource.create_bucket(Bucket=target)
 
-    s3_client = boto3.client("s3")
-    with pytest.raises(ClientError) as exc:
-        s3_client.copy_object(
-            Bucket=target, CopySource={"Bucket": src, "Key": "foofoofoo"}, Key="newkey"
-        )
-    err = exc.value.response["Error"]
-    assert err["Code"] == "NoSuchKey"
-    assert err["Message"] == "The specified key does not exist."
-    assert err["Key"] == "foofoofoo"
+    try:
+        s3_client = boto3.client("s3", "us-east-1")
+        with pytest.raises(ClientError) as exc:
+            s3_client.copy_object(
+                Bucket=target,
+                CopySource={"Bucket": bucket_name, "Key": "foofoofoo"},
+                Key="newkey",
+            )
+        err = exc.value.response["Error"]
+        assert err["Code"] == "NoSuchKey"
+        assert err["Message"] == "The specified key does not exist."
+        assert err["Key"] == "foofoofoo"
+    finally:
+        s3_client.delete_bucket(Bucket=target)
 
 
-@mock_s3
-def test_copy_object_with_versioning():
+@s3_aws_verified
+@pytest.mark.aws_verified
+def test_copy_object_with_versioning(bucket_name=None):
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
 
-    client.create_bucket(
-        Bucket="blah", CreateBucketConfiguration={"LocationConstraint": "eu-west-1"}
-    )
-    client.put_bucket_versioning(
-        Bucket="blah", VersioningConfiguration={"Status": "Enabled"}
-    )
+    enable_versioning(bucket_name, client)
 
-    client.put_object(Bucket="blah", Key="test1", Body=b"test1")
-    client.put_object(Bucket="blah", Key="test2", Body=b"test2")
+    client.put_object(Bucket=bucket_name, Key="test1", Body=b"test1")
+    client.put_object(Bucket=bucket_name, Key="test2", Body=b"test2")
 
-    _ = client.get_object(Bucket="blah", Key="test1")["VersionId"]
-    obj2_version = client.get_object(Bucket="blah", Key="test2")["VersionId"]
+    _ = client.get_object(Bucket=bucket_name, Key="test1")["VersionId"]
+    obj2_version = client.get_object(Bucket=bucket_name, Key="test2")["VersionId"]
 
     client.copy_object(
-        CopySource={"Bucket": "blah", "Key": "test1"}, Bucket="blah", Key="test2"
+        CopySource={"Bucket": bucket_name, "Key": "test1"},
+        Bucket=bucket_name,
+        Key="test2",
     )
-    obj2_version_new = client.get_object(Bucket="blah", Key="test2")["VersionId"]
+    obj2_version_new = client.get_object(Bucket=bucket_name, Key="test2")["VersionId"]
 
     # Version should be different to previous version
     assert obj2_version_new != obj2_version
 
     client.copy_object(
-        CopySource={"Bucket": "blah", "Key": "test2", "VersionId": obj2_version},
-        Bucket="blah",
+        CopySource={"Bucket": bucket_name, "Key": "test2", "VersionId": obj2_version},
+        Bucket=bucket_name,
         Key="test3",
     )
-    obj3_version_new = client.get_object(Bucket="blah", Key="test3")["VersionId"]
+    obj3_version_new = client.get_object(Bucket=bucket_name, Key="test3")["VersionId"]
     assert obj3_version_new != obj2_version_new
 
     # Copy file that doesn't exist
     with pytest.raises(ClientError) as exc:
         client.copy_object(
-            CopySource={"Bucket": "blah", "Key": "test4", "VersionId": obj2_version},
-            Bucket="blah",
+            CopySource={
+                "Bucket": bucket_name,
+                "Key": "test4",
+                "VersionId": obj2_version,
+            },
+            Bucket=bucket_name,
             Key="test5",
         )
-    assert exc.value.response["Error"]["Code"] == "NoSuchKey"
+    assert exc.value.response["Error"]["Code"] == "NoSuchVersion"
 
-    response = client.create_multipart_upload(Bucket="blah", Key="test4")
+    response = client.create_multipart_upload(Bucket=bucket_name, Key="test4")
     upload_id = response["UploadId"]
     response = client.upload_part_copy(
-        Bucket="blah",
+        Bucket=bucket_name,
         Key="test4",
-        CopySource={"Bucket": "blah", "Key": "test3", "VersionId": obj3_version_new},
+        CopySource={
+            "Bucket": bucket_name,
+            "Key": "test3",
+            "VersionId": obj3_version_new,
+        },
         UploadId=upload_id,
         PartNumber=1,
     )
     etag = response["CopyPartResult"]["ETag"]
     client.complete_multipart_upload(
-        Bucket="blah",
+        Bucket=bucket_name,
         Key="test4",
         UploadId=upload_id,
         MultipartUpload={"Parts": [{"ETag": etag, "PartNumber": 1}]},
     )
 
-    response = client.get_object(Bucket="blah", Key="test4")
+    response = client.get_object(Bucket=bucket_name, Key="test4")
     data = response["Body"].read()
     assert data == b"test2"
 
 
-@mock_s3
+@mock_aws
 def test_copy_object_from_unversioned_to_versioned_bucket():
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
+    src = str(uuid4())
+    dest = str(uuid4())
 
-    client.create_bucket(
-        Bucket="src", CreateBucketConfiguration={"LocationConstraint": "eu-west-1"}
-    )
-    client.create_bucket(
-        Bucket="dest", CreateBucketConfiguration={"LocationConstraint": "eu-west-1"}
-    )
+    client.create_bucket(Bucket=src)
+    client.create_bucket(Bucket=dest)
     client.put_bucket_versioning(
-        Bucket="dest", VersioningConfiguration={"Status": "Enabled"}
+        Bucket=dest, VersioningConfiguration={"Status": "Enabled"}
     )
 
-    client.put_object(Bucket="src", Key="test", Body=b"content")
+    client.put_object(Bucket=src, Key="test", Body=b"content")
 
     obj2_version_new = client.copy_object(
-        CopySource={"Bucket": "src", "Key": "test"}, Bucket="dest", Key="test"
+        CopySource={"Bucket": src, "Key": "test"}, Bucket=dest, Key="test"
     ).get("VersionId")
 
     # VersionId should be present in the response
     assert obj2_version_new is not None
 
 
-@mock_s3
+@mock_aws
 def test_copy_object_with_replacement_tagging():
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    client.create_bucket(Bucket="mybucket")
+    bucket_name = str(uuid4())
+    client.create_bucket(Bucket=bucket_name)
     client.put_object(
-        Bucket="mybucket", Key="original", Body=b"test", Tagging="tag=old"
+        Bucket=bucket_name, Key="original", Body=b"test", Tagging="tag=old"
     )
 
     # using system tags will fail
     with pytest.raises(ClientError) as err:
         client.copy_object(
-            CopySource={"Bucket": "mybucket", "Key": "original"},
-            Bucket="mybucket",
+            CopySource={"Bucket": bucket_name, "Key": "original"},
+            Bucket=bucket_name,
             Key="copy1",
             TaggingDirective="REPLACE",
             Tagging="aws:tag=invalid_key",
@@ -424,62 +438,59 @@ def test_copy_object_with_replacement_tagging():
     assert exc.response["Error"]["Code"] == "InvalidTag"
 
     client.copy_object(
-        CopySource={"Bucket": "mybucket", "Key": "original"},
-        Bucket="mybucket",
+        CopySource={"Bucket": bucket_name, "Key": "original"},
+        Bucket=bucket_name,
         Key="copy1",
         TaggingDirective="REPLACE",
         Tagging="tag=new",
     )
     client.copy_object(
-        CopySource={"Bucket": "mybucket", "Key": "original"},
-        Bucket="mybucket",
+        CopySource={"Bucket": bucket_name, "Key": "original"},
+        Bucket=bucket_name,
         Key="copy2",
         TaggingDirective="COPY",
     )
 
-    tags1 = client.get_object_tagging(Bucket="mybucket", Key="copy1")["TagSet"]
+    tags1 = client.get_object_tagging(Bucket=bucket_name, Key="copy1")["TagSet"]
     assert tags1 == [{"Key": "tag", "Value": "new"}]
-    tags2 = client.get_object_tagging(Bucket="mybucket", Key="copy2")["TagSet"]
+    tags2 = client.get_object_tagging(Bucket=bucket_name, Key="copy2")["TagSet"]
     assert tags2 == [{"Key": "tag", "Value": "old"}]
 
 
-@mock_s3
-@mock_kms
+@mock_aws
 def test_copy_object_with_kms_encryption():
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
     kms_client = boto3.client("kms", region_name=DEFAULT_REGION_NAME)
     kms_key = kms_client.create_key()["KeyMetadata"]["KeyId"]
 
-    client.create_bucket(
-        Bucket="blah", CreateBucketConfiguration={"LocationConstraint": "eu-west-1"}
-    )
+    bucket_name = str(uuid4())
+    client.create_bucket(Bucket=bucket_name)
 
-    client.put_object(Bucket="blah", Key="test1", Body=b"test1")
+    client.put_object(Bucket=bucket_name, Key="test1", Body=b"test1")
 
     client.copy_object(
-        CopySource={"Bucket": "blah", "Key": "test1"},
-        Bucket="blah",
+        CopySource={"Bucket": bucket_name, "Key": "test1"},
+        Bucket=bucket_name,
         Key="test2",
         SSEKMSKeyId=kms_key,
         ServerSideEncryption="aws:kms",
     )
-    result = client.head_object(Bucket="blah", Key="test2")
+    result = client.head_object(Bucket=bucket_name, Key="test2")
     assert result["SSEKMSKeyId"] == kms_key
     assert result["ServerSideEncryption"] == "aws:kms"
 
 
-@mock_s3
-@mock_kms
+@mock_aws
 def test_copy_object_in_place_with_encryption():
     kms_client = boto3.client("kms", region_name=DEFAULT_REGION_NAME)
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
     kms_key = kms_client.create_key()["KeyMetadata"]["KeyId"]
-    bucket = s3_resource.Bucket("test_bucket")
+    bucket = s3_resource.Bucket(str(uuid4()))
     bucket.create()
     key = "source-key"
     resp = client.put_object(
-        Bucket="test_bucket",
+        Bucket=bucket.name,
         Key=key,
         Body=b"somedata",
         ServerSideEncryption="aws:kms",
@@ -490,8 +501,8 @@ def test_copy_object_in_place_with_encryption():
 
     # assert that you can copy in place with the same Encryption settings
     client.copy_object(
-        Bucket="test_bucket",
-        CopySource=f"test_bucket/{key}",
+        Bucket=bucket.name,
+        CopySource=f"{bucket.name}/{key}",
         Key=key,
         ServerSideEncryption="aws:kms",
         BucketKeyEnabled=True,
@@ -500,8 +511,8 @@ def test_copy_object_in_place_with_encryption():
 
     # assert that the BucketKeyEnabled setting is not kept in the destination key
     resp = client.copy_object(
-        Bucket="test_bucket",
-        CopySource=f"test_bucket/{key}",
+        Bucket=bucket.name,
+        CopySource=f"{bucket.name}/{key}",
         Key=key,
         ServerSideEncryption="aws:kms",
         SSEKMSKeyId=kms_key,
@@ -512,8 +523,8 @@ def test_copy_object_in_place_with_encryption():
     # AWS allows you to not specify any fields as it will use AES256 by
     # default and is different from the source key.
     resp = client.copy_object(
-        Bucket="test_bucket",
-        CopySource=f"test_bucket/{key}",
+        Bucket=bucket.name,
+        CopySource=f"{bucket.name}/{key}",
         Key=key,
     )
     assert resp["ServerSideEncryption"] == "AES256"
@@ -521,15 +532,15 @@ def test_copy_object_in_place_with_encryption():
     # Check that it allows copying in the place with the same
     # ServerSideEncryption setting as the source.
     resp = client.copy_object(
-        Bucket="test_bucket",
-        CopySource=f"test_bucket/{key}",
+        Bucket=bucket.name,
+        CopySource=f"{bucket.name}/{key}",
         Key=key,
         ServerSideEncryption="AES256",
     )
     assert resp["ServerSideEncryption"] == "AES256"
 
 
-@mock_s3
+@mock_aws
 def test_copy_object_in_place_with_storage_class():
     """Validate setting StorageClass allows a copy in place.
 
@@ -537,7 +548,7 @@ def test_copy_object_in_place_with_storage_class():
     """
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "test-bucket"
+    bucket_name = str(uuid4())
     bucket = s3_resource.Bucket(bucket_name)
     bucket.create()
     key = "source-key"
@@ -555,18 +566,18 @@ def test_copy_object_in_place_with_storage_class():
     assert resp["StorageClass"] == "STANDARD"
 
 
-@mock_s3
+@mock_aws
 def test_copy_object_does_not_copy_storage_class():
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket = s3_resource.Bucket("test_bucket")
+    bucket = s3_resource.Bucket(str(uuid4()))
     bucket.create()
     source_key = "source-key"
     dest_key = "dest-key"
     bucket.put_object(Key=source_key, Body=b"somedata", StorageClass="STANDARD_IA")
     client.copy_object(
-        Bucket="test_bucket",
-        CopySource=f"test_bucket/{source_key}",
+        Bucket=bucket.name,
+        CopySource=f"{bucket.name}/{source_key}",
         Key=dest_key,
     )
 
@@ -576,11 +587,11 @@ def test_copy_object_does_not_copy_storage_class():
     assert keys[dest_key].storage_class == "STANDARD"
 
 
-@mock_s3
+@mock_aws
 def test_copy_object_does_not_copy_acl():
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "testbucket"
+    bucket_name = str(uuid4())
     bucket = s3_resource.Bucket(bucket_name)
     bucket.create()
     source_key = "source-key"
@@ -607,15 +618,13 @@ def test_copy_object_does_not_copy_acl():
     assert default_acl["Grants"] == dest_acl["Grants"]
 
 
-@mock_s3
-def test_copy_object_in_place_with_metadata():
+@s3_aws_verified
+@pytest.mark.aws_verified
+def test_copy_object_in_place_with_metadata(bucket_name=None):
     s3_resource = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "testbucket"
-    bucket = s3_resource.Bucket(bucket_name)
-    bucket.create()
     key_name = "source-key"
-    bucket.put_object(Key=key_name, Body=b"somedata")
+    s3_resource.Object(bucket_name, key_name).put(Body=b"somedata")
 
     # test that giving metadata is not enough and should provide
     # MetadataDirective=REPLACE on top.
@@ -644,10 +653,10 @@ def test_copy_object_in_place_with_metadata():
     assert result["Metadata"] == {}
 
 
-@mock_s3
+@mock_aws
 def test_copy_objet_legal_hold():
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "testbucket"
+    bucket_name = str(uuid4())
     source_key = "source-key"
     dest_key = "dest-key"
     client.create_bucket(Bucket=bucket_name, ObjectLockEnabledForBucket=True)
@@ -656,6 +665,7 @@ def test_copy_objet_legal_hold():
         Key=source_key,
         Body=b"somedata",
         ObjectLockLegalHoldStatus="ON",
+        ContentMD5=generate_content_md5(b"somedata"),
     )
 
     head_object = client.head_object(Bucket=bucket_name, Key=source_key)
@@ -676,10 +686,10 @@ def test_copy_objet_legal_hold():
     assert "ObjectLockLegalHoldStatus" not in head_object
 
 
-@mock_s3
+@mock_aws
 def test_s3_copy_object_lock():
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "testbucket"
+    bucket_name = str(uuid4())
     source_key = "source-key"
     dest_key = "dest-key"
     client.create_bucket(Bucket=bucket_name, ObjectLockEnabledForBucket=True)
@@ -692,9 +702,10 @@ def test_s3_copy_object_lock():
     client.put_object(
         Bucket=bucket_name,
         Key=source_key,
-        Body="test",
+        Body=b"test",
         ObjectLockMode="GOVERNANCE",
         ObjectLockRetainUntilDate=retain_until,
+        ContentMD5=generate_content_md5(b"test"),
     )
 
     head_object = client.head_object(Bucket=bucket_name, Key=source_key)
@@ -718,10 +729,10 @@ def test_s3_copy_object_lock():
     assert "ObjectLockRetainUntilDate" not in head_object
 
 
-@mock_s3
+@mock_aws
 def test_copy_object_in_place_website_redirect_location():
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "testbucket"
+    bucket_name = str(uuid4())
     key = "source-key"
     client.create_bucket(Bucket=bucket_name)
     # This test will validate that setting WebsiteRedirectLocation
@@ -749,11 +760,11 @@ def test_copy_object_in_place_website_redirect_location():
     assert head_object["WebsiteRedirectLocation"] == "/test/direct"
 
 
-@mock_s3
+@mock_aws
 def test_copy_object_in_place_with_bucket_encryption():
     # If a bucket has encryption configured, it will allow copy in place per default
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "test-bucket"
+    bucket_name = str(uuid4())
     client.create_bucket(Bucket=bucket_name)
     key = "source-key"
 
@@ -785,12 +796,70 @@ def test_copy_object_in_place_with_bucket_encryption():
     assert response["ServerSideEncryption"] == "AES256"
 
 
-@mock_s3
+@s3_aws_verified
+@pytest.mark.aws_verified
+def test_copy_object_in_place_with_versioning(bucket_name=None):
+    # If a bucket has versioning enabled, it will allow copy in place
+    client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
+    key = "source-key"
+
+    client.put_object(Body=b"", Bucket=bucket_name, Key=key)
+
+    enable_versioning(bucket_name, client)
+
+    response = client.put_object(Body=b"", Bucket=bucket_name, Key=key)
+    version_id = response["ResponseMetadata"]["HTTPHeaders"]["x-amz-version-id"]
+    assert version_id and version_id != "null"
+
+    response = client.copy_object(
+        Bucket=bucket_name,
+        CopySource={"Bucket": bucket_name, "Key": key, "VersionId": version_id},
+        Key=key,
+    )
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+
+    response = client.copy_object(
+        Bucket=bucket_name,
+        CopySource={"Bucket": bucket_name, "Key": key, "VersionId": "null"},
+        Key=key,
+    )
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+
+    response = client.list_object_versions(
+        Bucket=bucket_name,
+        Prefix=key,
+    )
+    assert len(response["Versions"]) == 4
+
+    # Copy-In-Place does not work if no other parameters are set
+    with pytest.raises(ClientError) as exc:
+        client.copy_object(
+            Bucket=bucket_name,
+            CopySource={"Bucket": bucket_name, "Key": key},
+            Key=key,
+        )
+    err = exc.value.response["Error"]
+    assert err["Code"] == "InvalidRequest"
+    assert (
+        err["Message"]
+        == "This copy request is illegal because it is trying to copy an object to itself without changing the object's metadata, storage class, website redirect location or encryption attributes."
+    )
+
+    # It does work when any other property is set
+    client.copy_object(
+        Bucket=bucket_name,
+        CopySource={"Bucket": bucket_name, "Key": key},
+        Key=key,
+        StorageClass="STANDARD",
+    )
+
+
+@mock_aws
 @pytest.mark.parametrize(
     "algorithm",
     ["CRC32", "SHA1", "SHA256"],
 )
-def test_copy_key_boto3_with_both_sha256_checksum(algorithm):
+def test_copy_key_with_both_sha256_checksum(algorithm):
     """Validate that moto S3 checksum calculations are correct.
 
     We first create an object with a Checksum calculated by boto, by
@@ -806,7 +875,7 @@ def test_copy_key_boto3_with_both_sha256_checksum(algorithm):
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
     source_key = "source-key"
     dest_key = "dest-key"
-    bucket = "foobar"
+    bucket = str(uuid4())
     body = b"checksum-test"
     client.create_bucket(Bucket=bucket)
 
@@ -832,7 +901,7 @@ def test_copy_key_boto3_with_both_sha256_checksum(algorithm):
     assert resp["CopyObjectResult"][checksum_key] == checksum_by_boto
 
 
-@mock_s3
+@mock_aws
 @pytest.mark.parametrize(
     "algorithm, checksum",
     [
@@ -845,18 +914,17 @@ def test_copy_object_calculates_checksum(algorithm, checksum):
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
     source_key = "source-key"
     dest_key = "dest-key"
-    bucket = "foobar"
+    bucket = str(uuid4())
     body = b"test-checksum"
     client.create_bucket(Bucket=bucket)
 
     checksum_key = f"Checksum{algorithm}"
 
-    resp = client.put_object(
+    client.put_object(
         Bucket=bucket,
         Key=source_key,
         Body=body,
     )
-    assert checksum_key not in resp
 
     resp = client.copy_object(
         Bucket=bucket,
@@ -869,12 +937,12 @@ def test_copy_object_calculates_checksum(algorithm, checksum):
     assert resp["CopyObjectResult"][checksum_key] == checksum
 
 
-@mock_s3
+@mock_aws
 def test_copy_object_keeps_checksum():
     client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
     source_key = "source-key"
     dest_key = "dest-key"
-    bucket = "foobar"
+    bucket = str(uuid4())
     body = b"test-checksum"
     expected_checksum = "1YQo81vx2VFUl0q5ccWISq8AkSBQQ0WO80S82TmfdIQ="
     client.create_bucket(Bucket=bucket)
@@ -899,3 +967,72 @@ def test_copy_object_keeps_checksum():
     # assert that it kept the checksum from the source key
     assert "ChecksumSHA256" in resp["CopyObjectResult"]
     assert resp["CopyObjectResult"]["ChecksumSHA256"] == expected_checksum
+
+
+@s3_aws_verified
+@pytest.mark.aws_verified
+def test_copy_source_if_none_match(bucket_name=None):
+    client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
+    s3 = boto3.resource("s3", region_name=DEFAULT_REGION_NAME)
+
+    enable_versioning(bucket_name, client)
+
+    obj = s3.Object(bucket_name, "orig")
+
+    etag = obj.put(Body=b"n/a")["ETag"]
+
+    # Exact match
+    copy_from_kwargs = {
+        "CopySource": {"Bucket": bucket_name, "Key": "orig"},
+        "CopySourceIfNoneMatch": etag,
+        "StorageClass": "STANDARD",
+    }
+
+    with pytest.raises(ClientError) as exc:
+        obj.copy_from(**copy_from_kwargs)
+    err = exc.value.response["Error"]
+    assert err["Code"] == "PreconditionFailed"
+    assert (
+        err["Message"]
+        == "At least one of the pre-conditions you specified did not hold"
+    )
+    assert err["Condition"] == "x-amz-copy-source-If-None-Match"
+
+    r = client.list_object_versions(Bucket=bucket_name)["Versions"]
+    assert len(r) == 1
+    assert r[0]["ETag"] == etag
+
+    # Match without quotes
+    copy_from_kwargs = {
+        "CopySource": {"Bucket": bucket_name, "Key": "orig"},
+        "CopySourceIfNoneMatch": etag[1:-1],
+        "StorageClass": "STANDARD",
+    }
+
+    with pytest.raises(ClientError) as exc:
+        obj.copy_from(**copy_from_kwargs)
+    err = exc.value.response["Error"]
+    assert err["Code"] == "PreconditionFailed"
+    assert (
+        err["Message"]
+        == "At least one of the pre-conditions you specified did not hold"
+    )
+    assert err["Condition"] == "x-amz-copy-source-If-None-Match"
+
+    r = client.list_object_versions(Bucket=bucket_name)["Versions"]
+    assert len(r) == 1
+    assert r[0]["ETag"] == etag
+
+    # No match - completely different etag
+    copy_from_kwargs = {
+        "CopySource": {"Bucket": bucket_name, "Key": "orig"},
+        "CopySourceIfNoneMatch": "unknown etag",
+        "StorageClass": "STANDARD",
+    }
+
+    obj.copy_from(**copy_from_kwargs)
+
+    r = client.list_object_versions(Bucket=bucket_name)["Versions"]
+    assert len(r) == 2
+    assert r[0]["ETag"] == r[1]["ETag"] == etag
+    assert r[0]["VersionId"] != r[1]["VersionId"]
