@@ -20,9 +20,9 @@ from tests.test_s3 import empty_bucket, s3_aws_verified
 def test_put_bucket_logging():
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
     wrong_region_client = boto3.client("s3", region_name="us-west-2")
-    bucket_name = "mybucket"
-    log_bucket = "logbucket"
-    wrong_region_bucket = "wrongregionlogbucket"
+    bucket_name = str(uuid4())
+    log_bucket = str(uuid4())
+    wrong_region_bucket = str(uuid4())
     s3_client.create_bucket(Bucket=bucket_name)
     # Adding the ACL for log-delivery later...
     s3_client.create_bucket(Bucket=log_bucket)
@@ -204,8 +204,8 @@ def test_put_bucket_logging():
 def test_log_file_is_created():
     # Create necessary buckets
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "mybucket"
-    log_bucket = "logbucket"
+    bucket_name = str(uuid4())
+    log_bucket = str(uuid4())
     s3_client.create_bucket(Bucket=bucket_name)
     s3_client.create_bucket(Bucket=log_bucket)
 
@@ -261,8 +261,8 @@ def test_log_file_is_created():
 
     # Verify files are created in the target (logging) bucket
     keys = [k["Key"] for k in s3_client.list_objects_v2(Bucket=log_bucket)["Contents"]]
-    assert len([k for k in keys if k.startswith("mybucket/")]) == 3
-    assert len([k for k in keys if not k.startswith("mybucket/")]) == 1
+    assert len([k for k in keys if k.startswith(f"{bucket_name}/")]) == 3
+    assert len([k for k in keys if not k.startswith(f"{bucket_name}/")]) == 1
 
     # Verify (roughly) files have the correct content
     contents = [
@@ -280,8 +280,8 @@ def test_invalid_bucket_logging_when_permissions_are_false():
         raise SkipTest("Can't patch permission logic in ServerMode")
 
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "mybucket"
-    log_bucket = "logbucket"
+    bucket_name = str(uuid4())
+    log_bucket = str(uuid4())
     s3_client.create_bucket(Bucket=bucket_name)
     s3_client.create_bucket(Bucket=log_bucket)
     with (
@@ -310,8 +310,8 @@ def test_valid_bucket_logging_when_permissions_are_true():
         raise SkipTest("Can't patch permission logic in ServerMode")
 
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    bucket_name = "mybucket"
-    log_bucket = "logbucket"
+    bucket_name = str(uuid4())
+    log_bucket = str(uuid4())
     s3_client.create_bucket(Bucket=bucket_name)
     s3_client.create_bucket(Bucket=log_bucket)
     with (
