@@ -1,19 +1,22 @@
+from uuid import uuid4
+
 import boto3
 
-from moto import mock_s3
+from moto import mock_aws
 from moto.s3.responses import DEFAULT_REGION_NAME
 
 
-@mock_s3
+@mock_aws
 def test_s3_returns_requestid():
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
-    resp = s3_client.create_bucket(Bucket="mybucket")
+    bucket_name = str(uuid4())
+    resp = s3_client.create_bucket(Bucket=bucket_name)
     _check_metadata(resp)
 
-    resp = s3_client.put_object(Bucket="mybucket", Key="steve", Body=b"is awesome")
+    resp = s3_client.put_object(Bucket=bucket_name, Key="steve", Body=b"is awesome")
     _check_metadata(resp)
 
-    resp = s3_client.get_object(Bucket="mybucket", Key="steve")
+    resp = s3_client.get_object(Bucket=bucket_name, Key="steve")
     _check_metadata(resp)
 
 
