@@ -1,12 +1,12 @@
-# -*- coding: utf-8 -*-
 import json
 import unittest
 
 import boto3
 import pytest
+import requests
 
 import moto.server as server
-from moto import mock_iam, mock_lambda, mock_logs, mock_secretsmanager, settings
+from moto import mock_aws, settings
 from tests.markers import requires_docker
 from tests.test_awslambda.test_lambda import get_test_zip_file1
 
@@ -19,9 +19,8 @@ def skip_in_server_mode():
         raise unittest.SkipTest("No point in testing this in ServerMode")
 
 
-@mock_secretsmanager
+@mock_aws
 def test_get_secret_value():
-
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
 
@@ -41,9 +40,8 @@ def test_get_secret_value():
     assert json_data["SecretString"] == "foo-secret"
 
 
-@mock_secretsmanager
+@mock_aws
 def test_get_secret_that_does_not_exist():
-
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
 
@@ -57,7 +55,7 @@ def test_get_secret_that_does_not_exist():
     assert json_data["__type"] == "ResourceNotFoundException"
 
 
-@mock_secretsmanager
+@mock_aws
 def test_get_secret_that_does_not_match():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -77,7 +75,7 @@ def test_get_secret_that_does_not_match():
     assert json_data["__type"] == "ResourceNotFoundException"
 
 
-@mock_secretsmanager
+@mock_aws
 def test_get_secret_that_has_no_value():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -101,9 +99,8 @@ def test_get_secret_that_has_no_value():
     assert json_data["__type"] == "ResourceNotFoundException"
 
 
-@mock_secretsmanager
+@mock_aws
 def test_create_secret():
-
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
 
@@ -127,9 +124,8 @@ def test_create_secret():
     assert json_data_2["Name"] == "test-secret-2"
 
 
-@mock_secretsmanager
+@mock_aws
 def test_describe_secret():
-
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
 
@@ -166,9 +162,8 @@ def test_describe_secret():
     assert json_data_2["Name"] == "test-secret-2"
 
 
-@mock_secretsmanager
+@mock_aws
 def test_describe_secret_that_does_not_exist():
-
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
 
@@ -183,9 +178,8 @@ def test_describe_secret_that_does_not_exist():
     assert json_data["__type"] == "ResourceNotFoundException"
 
 
-@mock_secretsmanager
+@mock_aws
 def test_describe_secret_that_does_not_match():
-
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
 
@@ -205,7 +199,7 @@ def test_describe_secret_that_does_not_match():
     assert json_data["__type"] == "ResourceNotFoundException"
 
 
-@mock_secretsmanager
+@mock_aws
 def test_rotate_secret():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -233,7 +227,7 @@ def test_rotate_secret():
     assert json_data["VersionId"] == client_request_token
 
 
-# @mock_secretsmanager
+# @mock_aws
 # def test_rotate_secret_enable_rotation():
 #     backend = server.create_backend_app('secretsmanager')
 #     test_client = backend.test_client()
@@ -291,7 +285,7 @@ def test_rotate_secret():
 #     assert json_data['RotationRules']['AutomaticallyAfterDays'] == 42
 
 
-@mock_secretsmanager
+@mock_aws
 def test_rotate_secret_that_does_not_exist():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -307,7 +301,7 @@ def test_rotate_secret_that_does_not_exist():
     assert json_data["__type"] == "ResourceNotFoundException"
 
 
-@mock_secretsmanager
+@mock_aws
 def test_rotate_secret_that_does_not_match():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -329,7 +323,7 @@ def test_rotate_secret_that_does_not_match():
     assert json_data["__type"] == "ResourceNotFoundException"
 
 
-@mock_secretsmanager
+@mock_aws
 def test_rotate_secret_that_is_still_rotating():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -373,7 +367,7 @@ def test_rotate_secret_that_is_still_rotating():
     assert rotate_secret.status_code == 400
 
 
-@mock_secretsmanager
+@mock_aws
 def test_rotate_secret_client_request_token_too_short():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -399,7 +393,7 @@ def test_rotate_secret_client_request_token_too_short():
     assert json_data["__type"] == "InvalidParameterException"
 
 
-@mock_secretsmanager
+@mock_aws
 def test_rotate_secret_client_request_token_too_long():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -427,7 +421,7 @@ def test_rotate_secret_client_request_token_too_long():
     assert json_data["__type"] == "InvalidParameterException"
 
 
-@mock_secretsmanager
+@mock_aws
 def test_rotate_secret_rotation_lambda_arn_too_long():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -453,10 +447,7 @@ def test_rotate_secret_rotation_lambda_arn_too_long():
     assert json_data["__type"] == "InvalidParameterException"
 
 
-@mock_iam
-@mock_lambda
-@mock_logs
-@mock_secretsmanager
+@mock_aws
 @requires_docker
 def test_rotate_secret_lambda_invocations():
     conn = boto3.client("iam", region_name="us-east-1")
@@ -501,10 +492,7 @@ def test_rotate_secret_lambda_invocations():
     assert len(logs["logStreams"]) == 4
 
 
-@mock_iam
-@mock_lambda
-@mock_logs
-@mock_secretsmanager
+@mock_aws
 def test_rotate_secret_with_incorrect_lambda_arn():
     secretsmanager_backend = server.create_backend_app("secretsmanager")
     secretsmanager_client = secretsmanager_backend.test_client()
@@ -526,7 +514,7 @@ def test_rotate_secret_with_incorrect_lambda_arn():
     assert resp.status_code == 404
 
 
-@mock_secretsmanager
+@mock_aws
 def test_put_secret_value_puts_new_secret():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -576,7 +564,7 @@ def test_put_secret_value_puts_new_secret():
     assert second_secret_json_data["SecretString"] == "foosecret"
 
 
-@mock_secretsmanager
+@mock_aws
 def test_put_secret_value_can_get_first_version_if_put_twice():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -634,7 +622,7 @@ def test_put_secret_value_can_get_first_version_if_put_twice():
     assert get_first_secret_json_data["SecretString"] == first_secret_string
 
 
-@mock_secretsmanager
+@mock_aws
 def test_put_secret_value_versions_differ_if_same_secret_put_twice():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -675,7 +663,7 @@ def test_put_secret_value_versions_differ_if_same_secret_put_twice():
     assert first_secret_version_id != second_secret_version_id
 
 
-@mock_secretsmanager
+@mock_aws
 def test_can_list_secret_version_ids():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -728,9 +716,8 @@ def test_can_list_secret_version_ids():
     ].sort() == returned_version_ids.sort()
 
 
-@mock_secretsmanager
+@mock_aws
 def test_get_resource_policy_secret():
-
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
 
@@ -751,7 +738,7 @@ def test_get_resource_policy_secret():
     assert json_data["Name"] == "test-secret"
 
 
-@mock_secretsmanager
+@mock_aws
 @pytest.mark.parametrize("pass_arn", [True, False])
 def test_update_secret_version_stage(pass_arn):
     custom_stage = "CUSTOM_STAGE"
@@ -819,7 +806,7 @@ def test_update_secret_version_stage(pass_arn):
     assert stages[new_version] == []
 
 
-@mock_secretsmanager
+@mock_aws
 def test_update_secret_version_stage_currentversion_handling():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -876,7 +863,7 @@ def test_update_secret_version_stage_currentversion_handling():
     assert stages[new_version] == ["AWSPREVIOUS"]
 
 
-@mock_secretsmanager
+@mock_aws
 def test_update_secret_version_stage_validation():
     backend = server.create_backend_app("secretsmanager")
     test_client = backend.test_client()
@@ -926,58 +913,145 @@ def test_update_secret_version_stage_validation():
     assert resp.status_code == 400
 
 
-#
-# The following tests should work, but fail on the embedded dict in
-# RotationRules. The error message suggests a problem deeper in the code, which
-# needs further investigation.
-#
+@mock_aws
+def test_batch_get_secret_value_for_secret_id_list_with_matches():
+    backend = server.create_backend_app("secretsmanager")
+    test_client = backend.test_client()
 
-# @mock_secretsmanager
-# def test_rotate_secret_rotation_period_zero():
-#     backend = server.create_backend_app('secretsmanager')
-#     test_client = backend.test_client()
+    test_client.post(
+        "/",
+        data={"Name": "db/username", "SecretString": "foo"},
+        headers={"X-Amz-Target": "secretsmanager.CreateSecret"},
+    )
 
-#     create_secret = test_client.post('/',
-#                         data={"Name": "test-secret",
-#                               "SecretString": "foosecret"},
-#                         headers={
-#                             "X-Amz-Target": "secretsmanager.CreateSecret"
-#                         },
-#                     )
+    test_client.post(
+        "/",
+        data={"Name": "db/password", "SecretString": "foo-password"},
+        headers={"X-Amz-Target": "secretsmanager.CreateSecret"},
+    )
 
-#     rotate_secret = test_client.post('/',
-#                         data={"SecretId": "test-secret",
-#                               "RotationRules": {"AutomaticallyAfterDays": 0}},
-#                         headers={
-#                             "X-Amz-Target": "secretsmanager.RotateSecret"
-#                         },
-#                     )
+    batch_get_secret_values = test_client.post(
+        "/",
+        json={"SecretIdList": ["db/username", "db/password"]},
+        headers={"X-Amz-Target": "secretsmanager.BatchGetSecretValue"},
+    )
 
-#     json_data = json.loads(rotate_secret.data.decode("utf-8"))
-#     assert json_data['message'] == "RotationRules.AutomaticallyAfterDays must be within 1-1000."
-#     assert json_data['__type'] == 'InvalidParameterException'
+    json_data = json.loads(batch_get_secret_values.data.decode("utf-8"))
+    matched = [
+        s
+        for s in json_data["SecretValues"]
+        if (s["Name"] == "db/username" and s["SecretString"] == "foo")
+        or (s["Name"] == "db/password" and s["SecretString"] == "foo-password")
+    ]
+    assert len(matched) == len(json_data["SecretValues"]) == 2
 
-# @mock_secretsmanager
-# def test_rotate_secret_rotation_period_too_long():
-#     backend = server.create_backend_app('secretsmanager')
-#     test_client = backend.test_client()
 
-#     create_secret = test_client.post('/',
-#                         data={"Name": "test-secret",
-#                               "SecretString": "foosecret"},
-#                         headers={
-#                             "X-Amz-Target": "secretsmanager.CreateSecret"
-#                         },
-#                     )
+@mock_aws
+def test_batch_get_secret_value_for_secret_id_list_with_no_matches():
+    backend = server.create_backend_app("secretsmanager")
+    test_client = backend.test_client()
 
-#     rotate_secret = test_client.post('/',
-#                         data={"SecretId": "test-secret",
-#                               "RotationRules": {"AutomaticallyAfterDays": 1001}},
-#                         headers={
-#                             "X-Amz-Target": "secretsmanager.RotateSecret"
-#                         },
-#                     )
+    test_client.post(
+        "/",
+        data={"Name": "db/foo", "SecretString": "bar"},
+        headers={"X-Amz-Target": "secretsmanager.CreateSecret"},
+    )
 
-#     json_data = json.loads(rotate_secret.data.decode("utf-8"))
-#     assert json_data['message'] == "RotationRules.AutomaticallyAfterDays must be within 1-1000."
-#     assert json_data['__type'] == 'InvalidParameterException'
+    batch_get_secret_values = test_client.post(
+        "/",
+        json={"SecretIdList": ["db/username", "db/password"]},
+        headers={"X-Amz-Target": "secretsmanager.BatchGetSecretValue"},
+    )
+
+    json_data = json.loads(batch_get_secret_values.data.decode("utf-8"))
+    assert len(json_data["SecretValues"]) == 0
+    assert len(json_data["Errors"]) == 2
+    assert json_data["Errors"][0]["SecretId"] == "db/username"
+    assert json_data["Errors"][0]["ErrorCode"] == "ResourceNotFoundException"
+    assert (
+        json_data["Errors"][0]["Message"]
+        == "Secrets Manager can't find the specified secret."
+    )
+    assert json_data["Errors"][1]["SecretId"] == "db/password"
+    assert json_data["Errors"][1]["ErrorCode"] == "ResourceNotFoundException"
+    assert (
+        json_data["Errors"][1]["Message"]
+        == "Secrets Manager can't find the specified secret."
+    )
+
+
+@mock_aws
+def test_batch_get_secret_value_with_both_secret_id_list_and_filters():
+    backend = server.create_backend_app("secretsmanager")
+    test_client = backend.test_client()
+
+    batch_get_secret_values = test_client.post(
+        "/",
+        json={
+            "SecretIdList": ["db/username", "db/password"],
+            "Filters": [{"Key": "description", "Values": ["foo"]}],
+        },
+        headers={"X-Amz-Target": "secretsmanager.BatchGetSecretValue"},
+    )
+
+    json_data = json.loads(batch_get_secret_values.data.decode("utf-8"))
+    assert (
+        json_data["message"]
+        == "Either 'SecretIdList' or 'Filters' must be provided, but not both."
+    )
+    assert json_data["__type"] == "InvalidParameterException"
+    assert batch_get_secret_values.status_code == 400
+
+
+@mock_aws
+def test_batch_get_secret_value_with_filters():
+    backend = server.create_backend_app("secretsmanager")
+    test_client = backend.test_client()
+
+    test_client.post(
+        "/",
+        data={"Name": "db/foo", "SecretString": "bar", "Description": "foo-secret"},
+        headers={"X-Amz-Target": "secretsmanager.CreateSecret"},
+    )
+
+    test_client.post(
+        "/",
+        data={"Name": "db/bar", "SecretString": "foo", "Description": "foo-secret"},
+        headers={"X-Amz-Target": "secretsmanager.CreateSecret"},
+    )
+
+    batch_get_secret_values = test_client.post(
+        "/",
+        json={
+            "Filters": [{"Key": "description", "Values": ["foo-secret"]}],
+        },
+        headers={"X-Amz-Target": "secretsmanager.BatchGetSecretValue"},
+    )
+
+    json_data = json.loads(batch_get_secret_values.data.decode("utf-8"))
+    matched = [
+        s
+        for s in json_data["SecretValues"]
+        if (s["Name"] == "db/foo" and s["SecretString"] == "bar")
+        or (s["Name"] == "db/bar" and s["SecretString"] == "foo")
+    ]
+
+    json_data = json.loads(batch_get_secret_values.data.decode("utf-8"))
+    assert len(json_data["SecretValues"]) == len(matched) == 2
+
+
+@mock_aws
+def test_data_api() -> None:
+    base_url = (
+        "http://localhost:5000"
+        if settings.TEST_SERVER_MODE
+        else "http://motoapi.amazonaws.com"
+    )
+    data_url = f"{base_url}/moto-api/data.json"
+    conn = boto3.client("secretsmanager", region_name="us-west-1")
+    conn.create_secret(Name="test-secret")
+    data = requests.post(data_url).json()
+    secrets = data["secretsmanager"]["FakeSecret"]
+    assert len(secrets) == 1
+    secret = secrets[0]
+    assert secret["name"] == "test-secret"
