@@ -1,14 +1,13 @@
 import json
 import os
 import re
-from datetime import datetime
+from datetime import datetime, timezone
 from unittest import SkipTest, mock
 from uuid import uuid4
 
 import boto3
 import pytest
 from botocore.exceptions import ClientError, ParamValidationError
-from dateutil.tz import tzutc
 
 from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
@@ -540,25 +539,56 @@ def test_state_machine_start_execution_with_custom_name():
 
 
 @mock_aws
-def test_state_machine_start_execution_fails_on_duplicate_execution_name():
+def test_state_machine_start_execution_fails_on_duplicate_execution_name_with_different_input():
     client = boto3.client("stepfunctions", region_name=region)
     #
     sm = client.create_state_machine(
         name="name", definition=str(simple_definition), roleArn=_get_default_role()
     )
     execution_one = client.start_execution(
-        stateMachineArn=sm["stateMachineArn"], name="execution_name"
+        stateMachineArn=sm["stateMachineArn"],
+        name="execution_name",
+        input='{"a": "b", "c": "d"}',
     )
     #
     with pytest.raises(ClientError) as ex:
         _ = client.start_execution(
-            stateMachineArn=sm["stateMachineArn"], name="execution_name"
+            stateMachineArn=sm["stateMachineArn"],
+            name="execution_name",
+            # Input is different (even though the decoded json is equivalent)
+            input='{"c": "d", "a": "b"}',
         )
     assert ex.value.response["Error"]["Message"] == (
         "Execution Already Exists: '" + execution_one["executionArn"] + "'"
     )
 
 
+@mock_aws
+def test_state_machine_start_execution_is_idempotent_by_name_and_input():
+    client = boto3.client("stepfunctions", region_name=region)
+    #
+    sm = client.create_state_machine(
+        name="name", definition=str(simple_definition), roleArn=_get_default_role()
+    )
+    execution_input = '{"a": "b", "c": "d"}'
+    execution_one = client.start_execution(
+        stateMachineArn=sm["stateMachineArn"],
+        name="execution_name",
+        input=execution_input,
+    )
+    #
+    execution_two = client.start_execution(
+        stateMachineArn=sm["stateMachineArn"],
+        name="execution_name",
+        input=execution_input,
+    )
+    assert execution_one["executionArn"] == execution_two["executionArn"]
+
+    # Check idempotency
+    list_execs = client.list_executions(stateMachineArn=sm["stateMachineArn"])
+    assert len(list_execs["executions"]) == 1
+
+
 @mock_aws
 def test_state_machine_start_execution_with_custom_input():
     client = boto3.client("stepfunctions", region_name=region)
@@ -827,7 +857,7 @@ def test_state_machine_get_execution_history_throws_error_with_unknown_execution
 def test_state_machine_get_execution_history_contains_expected_success_events_when_started():
     expected_events = [
         {
-            "timestamp": datetime(2020, 1, 1, 0, 0, 0, tzinfo=tzutc()),
+            "timestamp": datetime(2020, 1, 1, 0, 0, 0, tzinfo=timezone.utc),
             "type": "ExecutionStarted",
             "id": 1,
             "previousEventId": 0,
@@ -838,7 +868,7 @@ def test_state_machine_get_execution_history_contains_expected_success_events_wh
             },
         },
         {
-            "timestamp": datetime(2020, 1, 1, 0, 0, 10, tzinfo=tzutc()),
+            "timestamp": datetime(2020, 1, 1, 0, 0, 10, tzinfo=timezone.utc),
             "type": "PassStateEntered",
             "id": 2,
             "previousEventId": 0,
@@ -849,7 +879,7 @@ def test_state_machine_get_execution_history_contains_expected_success_events_wh
             },
         },
         {
-            "timestamp": datetime(2020, 1, 1, 0, 0, 10, tzinfo=tzutc()),
+            "timestamp": datetime(2020, 1, 1, 0, 0, 10, tzinfo=timezone.utc),
             "type": "PassStateExited",
             "id": 3,
             "previousEventId": 2,
@@ -860,7 +890,7 @@ def test_state_machine_get_execution_history_contains_expected_success_events_wh
             },
         },
         {
-            "timestamp": datetime(2020, 1, 1, 0, 0, 20, tzinfo=tzutc()),
+            "timestamp": datetime(2020, 1, 1, 0, 0, 20, tzinfo=timezone.utc),
             "type": "ExecutionSucceeded",
             "id": 4,
             "previousEventId": 3,
@@ -922,7 +952,7 @@ def test_state_machine_get_execution_history_contains_expected_failure_events_wh
         raise SkipTest("Cant pass environment variable in server mode")
     expected_events = [
         {
-            "timestamp": datetime(2020, 1, 1, 0, 0, 0, tzinfo=tzutc()),
+            "timestamp": datetime(2020, 1, 1, 0, 0, 0, tzinfo=timezone.utc),
             "type": "ExecutionStarted",
             "id": 1,
             "previousEventId": 0,
@@ -933,7 +963,7 @@ def test_state_machine_get_execution_history_contains_expected_failure_events_wh
             },
         },
         {
-            "timestamp": datetime(2020, 1, 1, 0, 0, 10, tzinfo=tzutc()),
+            "timestamp": datetime(2020, 1, 1, 0, 0, 10, tzinfo=timezone.utc),
             "type": "FailStateEntered",
             "id": 2,
             "previousEventId": 0,
@@ -944,7 +974,7 @@ def test_state_machine_get_execution_history_contains_expected_failure_events_wh
             },
         },
         {
-            "timestamp": datetime(2020, 1, 1, 0, 0, 10, tzinfo=tzutc()),
+            "timestamp": datetime(2020, 1, 1, 0, 0, 10, tzinfo=timezone.utc),
             "type": "ExecutionFailed",
             "id": 3,
             "previousEventId": 2,
