@@ -1,3 +1,5 @@
+import json
+
 import boto3
 import pytest
 from botocore.exceptions import ClientError
@@ -495,3 +497,278 @@ def test_update_access_log_subscription_not_found():
     err = exc.value.response["Error"]
     assert err["Code"] == "ResourceNotFoundException"
     assert err["Message"] == "Access Log Subscription als-invalid-id123 not found"
+
+
+@mock_aws
+def test_put_auth_policy():
+    client = boto3.client("vpc-lattice", region_name="us-west-2")
+
+    svc = client.create_service(name="my-service", authType="AWS_IAM")
+    sn = client.create_service_network(name="my-sn", authType="NONE")
+
+    policy_document = json.dumps(
+        {
+            "Version": "2012-10-17",
+            "Statement": [
+                {
+                    "Effect": "Allow",
+                    "Principal": "*",
+                    "Action": "vpc-lattice-svcs:Invoke",
+                    "Resource": svc["arn"],
+                }
+            ],
+        }
+    )
+
+    put_resp = client.put_auth_policy(
+        resourceIdentifier=svc["arn"],
+        policy=policy_document,
+    )
+
+    assert put_resp["policy"] == policy_document
+    assert put_resp["state"] == "Active"
+
+    put_resp = client.put_auth_policy(
+        resourceIdentifier=sn["arn"],
+        policy=policy_document,
+    )
+
+    assert put_resp["policy"] == policy_document
+    assert put_resp["state"] == "Inactive"
+
+
+@mock_aws
+def test_update_auth_policy():
+    client = boto3.client("vpc-lattice", region_name="us-west-2")
+
+    resp = client.create_service(name="my-service", authType="AWS_IAM")
+
+    policy_document = {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Effect": "Allow",
+                "Principal": "*",
+                "Action": "vpc-lattice-svcs:Invoke",
+                "Resource": resp["arn"],
+            }
+        ],
+    }
+
+    put_resp = client.put_auth_policy(
+        resourceIdentifier=resp["arn"],
+        policy=json.dumps(policy_document),
+    )
+
+    assert put_resp["policy"] == json.dumps(policy_document)
+
+    policy_document["Statement"][0]["Effect"] = "Deny"
+
+    put_resp = client.put_auth_policy(
+        resourceIdentifier=resp["arn"],
+        policy=json.dumps(policy_document),
+    )
+
+    assert put_resp["policy"] == json.dumps(policy_document)
+    assert put_resp["state"] == "Active"
+
+
+@mock_aws
+def test_get_auth_policy():
+    client = boto3.client("vpc-lattice", region_name="us-west-2")
+
+    svc = client.create_service(name="my-service", authType="NONE")
+    sn = client.create_service_network(name="my-sn", authType="AWS_IAM")
+
+    policy_document = json.dumps(
+        {
+            "Version": "2012-10-17",
+            "Statement": [
+                {
+                    "Effect": "Allow",
+                    "Principal": "*",
+                    "Action": "vpc-lattice-svcs:Invoke",
+                    "Resource": svc["arn"],
+                }
+            ],
+        }
+    )
+
+    client.put_auth_policy(
+        resourceIdentifier=svc["arn"],
+        policy=policy_document,
+    )
+
+    resp = client.get_auth_policy(resourceIdentifier=svc["arn"])
+
+    assert resp["policy"] == policy_document
+    assert resp["state"] == "Inactive"
+
+    resp = client.put_auth_policy(
+        resourceIdentifier=sn["arn"],
+        policy=policy_document,
+    )
+
+    resp = client.get_auth_policy(resourceIdentifier=sn["arn"])
+
+    assert resp["policy"] == policy_document
+    assert resp["state"] == "Active"
+
+
+@mock_aws
+def test_auth_policy_resource_not_found():
+    client = boto3.client("vpc-lattice", region_name="us-west-2")
+
+    id = "svc-invalid-id123"
+    with pytest.raises(ClientError) as exc:
+        client.get_auth_policy(resourceIdentifier=id)
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == f"Resource {id} not found"
+
+    with pytest.raises(ClientError) as exc:
+        client.delete_auth_policy(resourceIdentifier=id)
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == f"Resource {id} not found"
+
+    with pytest.raises(ClientError) as exc:
+        client.put_auth_policy(resourceIdentifier=id, policy="{}")
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == f"Resource {id} not found"
+
+
+@mock_aws
+def test_auth_policy_invalid_parameter():
+    client = boto3.client("vpc-lattice", region_name="us-west-2")
+
+    with pytest.raises(ClientError) as exc:
+        client.put_auth_policy(resourceIdentifier="invalid-id1234567", policy="{}")
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ValidationException"
+    assert (
+        err["Message"]
+        == "Invalid parameter resourceIdentifier, must start with 'sn-' or 'svc-'"
+    )
+
+
+@mock_aws
+def test_delete_auth_policy():
+    client = boto3.client("vpc-lattice", region_name="us-west-2")
+
+    resp = client.create_service(name="my-service", authType="NONE")
+
+    policy_document = json.dumps(
+        {
+            "Version": "2012-10-17",
+            "Statement": [
+                {
+                    "Effect": "Allow",
+                    "Principal": "*",
+                    "Action": "vpc-lattice-svcs:Invoke",
+                    "Resource": resp["arn"],
+                }
+            ],
+        }
+    )
+
+    client.put_auth_policy(
+        resourceIdentifier=resp["arn"],
+        policy=policy_document,
+    )
+
+    client.delete_auth_policy(resourceIdentifier=resp["arn"])
+
+    with pytest.raises(ClientError) as exc:
+        client.get_auth_policy(resourceIdentifier=resp["arn"])
+    err = exc.value.response["Error"]
+
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == f"Resource {resp['arn']} not found"
+
+
+@mock_aws
+def test_put_resource_policy():
+    client = boto3.client("vpc-lattice", region_name="us-west-2")
+
+    resp = client.create_service(name="my-service", authType="NONE")
+
+    policy_document = json.dumps(
+        {
+            "Version": "2012-10-17",
+            "Statement": [
+                {
+                    "Effect": "Allow",
+                    "Principal": "*",
+                    "Action": "vpc-lattice-svcs:Invoke",
+                    "Resource": resp["arn"],
+                }
+            ],
+        }
+    )
+
+    client.put_resource_policy(
+        resourceArn=resp["arn"],
+        policy=policy_document,
+    )
+
+    resp = client.get_resource_policy(resourceArn=resp["arn"])
+
+    assert resp["policy"] == policy_document
+
+
+@mock_aws
+def test_resource_policy_not_found():
+    client = boto3.client("vpc-lattice", region_name="us-west-2")
+
+    arn = "arn:aws:vpc-lattice:us-west-2:123456789012:service/svc-invalid-id123"
+    with pytest.raises(ClientError) as exc:
+        client.get_resource_policy(resourceArn=arn)
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == f"Resource {arn} not found"
+
+    with pytest.raises(ClientError) as exc:
+        client.delete_resource_policy(resourceArn=arn)
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == f"Resource {arn} not found"
+
+
+@mock_aws
+def test_delete_resource_policy():
+    client = boto3.client("vpc-lattice", region_name="us-west-2")
+
+    resp = client.create_service(name="my-service", authType="NONE")
+
+    arn = resp["arn"]
+    policy_document = json.dumps(
+        {
+            "Version": "2012-10-17",
+            "Statement": [
+                {
+                    "Effect": "Allow",
+                    "Principal": "*",
+                    "Action": "vpc-lattice-svcs:Invoke",
+                    "Resource": resp["arn"],
+                }
+            ],
+        }
+    )
+
+    client.put_resource_policy(
+        resourceArn=arn,
+        policy=policy_document,
+    )
+
+    resp = client.get_resource_policy(resourceArn=arn)
+    assert resp["policy"] == policy_document
+
+    client.delete_resource_policy(resourceArn=arn)
+
+    with pytest.raises(ClientError) as exc:
+        client.delete_resource_policy(resourceArn=arn)
+    err = exc.value.response["Error"]
+    assert err["Code"] == "ResourceNotFoundException"
+    assert err["Message"] == f"Resource {arn} not found"
